@@ -15,15 +15,17 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-#
-from typing import Any, Dict, Optional
+from __future__ import annotations
+
+from typing import TYPE_CHECKING, Any
 
 from airflow.providers.apache.spark.hooks.spark_jdbc import SparkJDBCHook
 from airflow.providers.apache.spark.operators.spark_submit import SparkSubmitOperator
-from airflow.utils.decorators import apply_defaults
+
+if TYPE_CHECKING:
+    from airflow.utils.context import Context
 
 
-# pylint: disable=too-many-instance-attributes
 class SparkJDBCOperator(SparkSubmitOperator):
     """
     This operator extends the SparkSubmitOperator specifically for performing data
@@ -36,80 +38,53 @@ class SparkJDBCOperator(SparkSubmitOperator):
         :ref:`howto/operator:SparkJDBCOperator`
 
     :param spark_app_name: Name of the job (default airflow-spark-jdbc)
-    :type spark_app_name: str
     :param spark_conn_id: The :ref:`spark connection id <howto/connection:spark>`
         as configured in Airflow administration
-    :type spark_conn_id: str
     :param spark_conf: Any additional Spark configuration properties
-    :type spark_conf: dict
     :param spark_py_files: Additional python files used (.zip, .egg, or .py)
-    :type spark_py_files: str
     :param spark_files: Additional files to upload to the container running the job
-    :type spark_files: str
     :param spark_jars: Additional jars to upload and add to the driver and
                        executor classpath
-    :type spark_jars: str
     :param num_executors: number of executor to run. This should be set so as to manage
                           the number of connections made with the JDBC database
-    :type num_executors: int
     :param executor_cores: Number of cores per executor
-    :type executor_cores: int
     :param executor_memory: Memory per executor (e.g. 1000M, 2G)
-    :type executor_memory: str
     :param driver_memory: Memory allocated to the driver (e.g. 1000M, 2G)
-    :type driver_memory: str
     :param verbose: Whether to pass the verbose flag to spark-submit for debugging
-    :type verbose: bool
     :param keytab: Full path to the file that contains the keytab
-    :type keytab: str
     :param principal: The name of the kerberos principal used for keytab
-    :type principal: str
     :param cmd_type: Which way the data should flow. 2 possible values:
                      spark_to_jdbc: data written by spark from metastore to jdbc
                      jdbc_to_spark: data written by spark from jdbc to metastore
-    :type cmd_type: str
     :param jdbc_table: The name of the JDBC table
-    :type jdbc_table: str
     :param jdbc_conn_id: Connection id used for connection to JDBC database
-    :type jdbc_conn_id: str
     :param jdbc_driver: Name of the JDBC driver to use for the JDBC connection. This
                         driver (usually a jar) should be passed in the 'jars' parameter
-    :type jdbc_driver: str
     :param metastore_table: The name of the metastore table,
-    :type metastore_table: str
     :param jdbc_truncate: (spark_to_jdbc only) Whether or not Spark should truncate or
                          drop and recreate the JDBC table. This only takes effect if
                          'save_mode' is set to Overwrite. Also, if the schema is
                          different, Spark cannot truncate, and will drop and recreate
-    :type jdbc_truncate: bool
     :param save_mode: The Spark save-mode to use (e.g. overwrite, append, etc.)
-    :type save_mode: str
     :param save_format: (jdbc_to_spark-only) The Spark save-format to use (e.g. parquet)
-    :type save_format: str
     :param batch_size: (spark_to_jdbc only) The size of the batch to insert per round
                        trip to the JDBC database. Defaults to 1000
-    :type batch_size: int
     :param fetch_size: (jdbc_to_spark only) The size of the batch to fetch per round trip
                        from the JDBC database. Default depends on the JDBC driver
-    :type fetch_size: int
     :param num_partitions: The maximum number of partitions that can be used by Spark
                            simultaneously, both for spark_to_jdbc and jdbc_to_spark
                            operations. This will also cap the number of JDBC connections
                            that can be opened
-    :type num_partitions: int
     :param partition_column: (jdbc_to_spark-only) A numeric column to be used to
                              partition the metastore table by. If specified, you must
                              also specify:
                              num_partitions, lower_bound, upper_bound
-    :type partition_column: str
     :param lower_bound: (jdbc_to_spark-only) Lower bound of the range of the numeric
                         partition column to fetch. If specified, you must also specify:
                         num_partitions, partition_column, upper_bound
-    :type lower_bound: int
     :param upper_bound: (jdbc_to_spark-only) Upper bound of the range of the numeric
                         partition column to fetch. If specified, you must also specify:
                         num_partitions, partition_column, lower_bound
-    :type upper_bound: int
     :param create_table_column_types: (spark_to_jdbc-only) The database column data types
                                       to use instead of the defaults, when creating the
                                       table. Data type information should be specified in
@@ -119,39 +94,37 @@ class SparkJDBCOperator(SparkSubmitOperator):
                                       types.
     """
 
-    # pylint: disable=too-many-arguments,too-many-locals
-    @apply_defaults
     def __init__(
         self,
         *,
-        spark_app_name: str = 'airflow-spark-jdbc',
-        spark_conn_id: str = 'spark-default',
-        spark_conf: Optional[Dict[str, Any]] = None,
-        spark_py_files: Optional[str] = None,
-        spark_files: Optional[str] = None,
-        spark_jars: Optional[str] = None,
-        num_executors: Optional[int] = None,
-        executor_cores: Optional[int] = None,
-        executor_memory: Optional[str] = None,
-        driver_memory: Optional[str] = None,
+        spark_app_name: str = "airflow-spark-jdbc",
+        spark_conn_id: str = "spark-default",
+        spark_conf: dict[str, Any] | None = None,
+        spark_py_files: str | None = None,
+        spark_files: str | None = None,
+        spark_jars: str | None = None,
+        num_executors: int | None = None,
+        executor_cores: int | None = None,
+        executor_memory: str | None = None,
+        driver_memory: str | None = None,
         verbose: bool = False,
-        principal: Optional[str] = None,
-        keytab: Optional[str] = None,
-        cmd_type: str = 'spark_to_jdbc',
-        jdbc_table: Optional[str] = None,
-        jdbc_conn_id: str = 'jdbc-default',
-        jdbc_driver: Optional[str] = None,
-        metastore_table: Optional[str] = None,
+        principal: str | None = None,
+        keytab: str | None = None,
+        cmd_type: str = "spark_to_jdbc",
+        jdbc_table: str | None = None,
+        jdbc_conn_id: str = "jdbc-default",
+        jdbc_driver: str | None = None,
+        metastore_table: str | None = None,
         jdbc_truncate: bool = False,
-        save_mode: Optional[str] = None,
-        save_format: Optional[str] = None,
-        batch_size: Optional[int] = None,
-        fetch_size: Optional[int] = None,
-        num_partitions: Optional[int] = None,
-        partition_column: Optional[str] = None,
-        lower_bound: Optional[str] = None,
-        upper_bound: Optional[str] = None,
-        create_table_column_types: Optional[str] = None,
+        save_mode: str | None = None,
+        save_format: str | None = None,
+        batch_size: int | None = None,
+        fetch_size: int | None = None,
+        num_partitions: int | None = None,
+        partition_column: str | None = None,
+        lower_bound: str | None = None,
+        upper_bound: str | None = None,
+        create_table_column_types: str | None = None,
         **kwargs: Any,
     ) -> None:
         super().__init__(**kwargs)
@@ -183,9 +156,9 @@ class SparkJDBCOperator(SparkSubmitOperator):
         self._lower_bound = lower_bound
         self._upper_bound = upper_bound
         self._create_table_column_types = create_table_column_types
-        self._hook: Optional[SparkJDBCHook] = None
+        self._hook: SparkJDBCHook | None = None
 
-    def execute(self, context: Dict[str, Any]) -> None:
+    def execute(self, context: Context) -> None:
         """Call the SparkSubmitHook to run the provided spark job"""
         if self._hook is None:
             self._hook = self._get_hook()
